@@ -386,9 +386,10 @@ class FormMixin:
             data["onchange"] = absolute_url(self.request, f"on_change={name}")
         if name in self._actions:
             cls = ENDPOINTS[self._actions[name]]
-            if cls.instantiate(self.request, self).check_permission():
+            endpoint = cls.instantiate(self.request, self)
+            if endpoint.check_permission():
                 data.update(
-                    action=cls.get_api_metadata(
+                    action=endpoint.get_api_metadata(
                         self.request, absolute_url(self.request)
                     )
                 )
@@ -460,6 +461,7 @@ class FormMixin:
                 dict(type="error", text="Por favor, corrija os erros.", errors=errors)
             )
         else:
+            self.cleaned_data.update(**data)
             data.update(
                 {
                     field_name: self.cleaned_data.get(field_name)
@@ -475,7 +477,7 @@ class FormMixin:
                         fieldname = attr_name.replace('clean_', '')
                         raise JsonResponseException(dict(type="error", text="Por favor, corrija os erros.", errors={fieldname: ''.join(e.messages)}))
             with transaction.atomic():
-                self.cleaned_data = data
+                
                 if isinstance(self, DjangoModelForm):
                     self.instance.pre_save()
                     for inline_field_name in inline_fields:
